print('#import the items')
print('import extraEncodings.ciphers as ciphers')
print('from ciphers import *')
print('#make the encoding.')
print("#The rate argument shows changes the dict. For example is it's 3 then a:3 A:6 b:9 B:12 and so on and forth.") 
print('#encoding = Encoding(3)')
print('#this prints the encoding dict')
print('#print(encoding.encoding)')
print('#this prints the decodsing dict')
print('#print(encoding.encoding.rev_dict)')
print('# this prints the value  that is contained in key A in the encoding dictionary')
print("#print(encoding.encoding['A'])")
print('#this prints the value that is contained in key 6   in the decoding dictionary')
print('#print(encoding.encoding.rev_dict[6])')
print('#Notes')
print('# Decode with instance.encoding.rev_dict')
print('#encode with instance.encoding')
print('# This is a list encoding')
print('#x = ListEncoding(4)')
print('# enocde / deocde like this')
print("#x.encode('Stuuf I want to decode')")